@@ -3,6 +3,7 @@ Super master handler for each user of Jaseci, serves as main interface between
 between user and Jaseci
 """
 
+from jaseci.api.jsorc_api import JsOrcApi
 from jaseci.element.master import Master
 from jaseci.api.logger_api import LoggerApi
 from jaseci.api.config_api import ConfigApi
@@ -11,7 +12,9 @@ from jaseci.api.super_api import SuperApi
 from jaseci.api.actions_api import ActionsApi
 
 
-class SuperMaster(Master, LoggerApi, ActionsApi, ConfigApi, GlobalApi, SuperApi):
+class SuperMaster(
+    Master, LoggerApi, ActionsApi, ConfigApi, GlobalApi, SuperApi, JsOrcApi
+):
     """Master with admin APIs"""
 
     def __init__(self, *args, **kwargs):
