@@ -374,7 +374,7 @@ class JacTests(TestCaseHelper, TestCase):
 
         res = mast.general_interface_to_api(
             api_name="walker_queue_wait",
-            params={"task_id": res["result"]},
+            params={"task_id": res["result"], "timeout": 15},
         )
 
         self.assertEqual("test", res["result"]["anchor"])
@@ -405,7 +405,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_async_syntax_without_celery(self):
         mast = self.meta.build_master()
-        mast._h.task.state = ServiceState.DISABLED
+        mast._h.task.state = ServiceState.NOT_STARTED
         mast.sentinel_register(name="test", code=jtp.async_syntax, auto_run="")
         res = mast.general_interface_to_api(
             api_name="walker_run",
@@ -446,7 +446,7 @@ class JacTests(TestCaseHelper, TestCase):
 
         res = mast.general_interface_to_api(
             api_name="walker_queue_wait",
-            params={"task_id": res["result"]},
+            params={"task_id": res["result"], "timeout": 15},
         )
 
         self.assertEqual("test", res["result"]["anchor"])
@@ -477,7 +477,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_async_sync_syntax_without_celery(self):
         mast = self.meta.build_master()
-        mast._h.task.state = ServiceState.DISABLED
+        mast._h.task.state = ServiceState.NOT_STARTED
         mast.sentinel_register(name="test", code=jtp.async_syntax, auto_run="")
         res = mast.general_interface_to_api(
             api_name="walker_run",
@@ -508,7 +508,7 @@ class JacTests(TestCaseHelper, TestCase):
 
     def test_block_scope_check(self):
         mast = self.meta.build_master()
-        mast._h.task.state = ServiceState.DISABLED
+        mast._h.task.state = ServiceState.NOT_STARTED
         mast.sentinel_register(name="test", code=jtp.block_scope_check, auto_run="")
         res = mast.general_interface_to_api(
             api_name="walker_run",
